@@ -54,7 +54,9 @@
 
 /*** DOCUMENTATION
 	<application name="AMD" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			Attempt to detect answering machines.
 		</synopsis>
