@@ -39,7 +39,9 @@
 
 /*** DOCUMENTATION
 	<application name="ResetCDR" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Resets the Call Data Record.
 		</synopsis>
@@ -89,7 +91,7 @@ struct app_cdr_message_payload {
 	const char *channel_name;
 	/*! Reset the CDR */
 	unsigned int reset:1;
-	/*! If reseting the CDR, keep the variables */
+	/*! If resetting the CDR, keep the variables */
 	unsigned int keep_variables:1;
 };
 
