@@ -52,7 +52,9 @@
 
 /*** DOCUMENTATION
 	<application name="ExternalIVR" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Interfaces with an external IVR application.
 		</synopsis>
@@ -835,7 +837,7 @@ static int eivr_comm(struct ast_channel *chan, struct ivr_localuser *u,
 				}
 			} else if (input[0] == EIVR_CMD_GET) {
 				char response[2048];
-				ast_verb(4, "Retriving Variables from channel: %s\n", &input[2]);
+				ast_verb(4, "Retrieving Variables from channel: %s\n", &input[2]);
 				ast_eivr_getvariable(chan, &input[2], response, sizeof(response));
 				send_eivr_event(eivr_events, 'G', response, chan);
 			} else if (input[0] == EIVR_CMD_SVAR) {
@@ -845,7 +847,7 @@ static int eivr_comm(struct ast_channel *chan, struct ivr_localuser *u,
 				ast_chan_log(LOG_NOTICE, chan, "Log message from EIVR: %s\n", &input[2]);
 			} else if (input[0] == EIVR_CMD_XIT) {
 				ast_chan_log(LOG_NOTICE, chan, "Exiting: %s\n", &input[2]);
-				ast_chan_log(LOG_WARNING, chan, "e'X'it command is depricated, use 'E'xit instead\n");
+				ast_chan_log(LOG_WARNING, chan, "e'X'it command is deprecated, use 'E'xit instead\n");
 				res = 0;
 				break;
 			} else if (input[0] == EIVR_CMD_EXIT) {
