@@ -40,7 +40,9 @@ static char *app_log = "Log";
 
 /*** DOCUMENTATION
 	<application name="Verbose" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.0.0</version>
+		</since>
  		<synopsis>
 			Send arbitrary text to verbose output.
 		</synopsis>
@@ -57,7 +59,9 @@ static char *app_log = "Log";
 		</description>
 	</application>
 	<application name="Log" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			Send arbitrary text to a selected log level.
 		</synopsis>
