@@ -37,7 +37,9 @@
 
 /*** DOCUMENTATION
 	<application name="While" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Start a while loop.
 		</synopsis>
@@ -55,7 +57,9 @@
 		</see-also>
 	</application>
 	<application name="EndWhile" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			End a while loop.
 		</synopsis>
@@ -70,7 +74,9 @@
 		</see-also>
 	</application>
 	<application name="ExitWhile" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			End a While loop.
 		</synopsis>
@@ -85,7 +91,9 @@
 		</see-also>
 	</application>
 	<application name="ContinueWhile" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			Restart a While loop.
 		</synopsis>
