@@ -40,7 +40,9 @@
 
 /*** DOCUMENTATION
 	<function name="AST_CONFIG" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.1.0</version>
+		</since>
 		<synopsis>
 			Retrieve a variable from a configuration file.
 		</synopsis>
