@@ -217,6 +217,8 @@ struct ast_sip_session {
 	unsigned int defer_terminate:1;
 	/*! Termination requested while termination deferred */
 	unsigned int terminate_while_deferred:1;
+	/*! Transferhandling ari */
+	unsigned int transferhandling_ari:1;
 	/*! Deferred incoming re-invite */
 	pjsip_rx_data *deferred_reinvite;
 	/*! Current T.38 state */
@@ -963,4 +965,29 @@ struct ast_sip_session_media *ast_sip_session_media_get_transport(struct ast_sip
  */
 const char *ast_sip_session_get_name(const struct ast_sip_session *session);
 
+/*!
+ * \brief Determines if the Connected Line info can be presented for this session
+ *
+ * \param session The session
+ * \param id The Connected Line info to evaluate
+ *
+ * \retval 1 The Connected Line info can be presented
+ * \retval 0 The Connected Line info cannot be presented
+ */
+int ast_sip_can_present_connected_id(const struct ast_sip_session *session, const struct ast_party_id *id);
+
+/*!
+ * \brief Adds a Reason header in the next reponse to an incoming INVITE
+ *
+ * \param session The session
+ * \param protocol Usually "SIP" but may be "STIR" for stir-shaken
+ * \param code SIP response code
+ * \param text Reason string
+ *
+ * \retval 0 the header is accepted
+ * \retval -1 the header is rejected
+ */
+int ast_sip_session_add_reason_header(struct ast_sip_session *session,
+	const char *protocol, int code, const char *text);
+
 #endif /* _RES_PJSIP_SESSION_H */
