@@ -509,7 +509,7 @@ static char *handle_debug_or_trace(int handler, struct ast_cli_entry *e, int cmd
 				}
 				AST_RWLIST_REMOVE(modules, ml, entry);
 				if (AST_RWLIST_EMPTY(modules)) {
-					ast_clear_flag(&ast_options, module_option);
+					ast_clear_flag64(&ast_options, module_option);
 				}
 				AST_RWLIST_UNLOCK(modules);
 				ast_cli(a->fd, "Core %s was %u and has been set to 0 for '%s'.\n", handler_name,
@@ -537,7 +537,7 @@ static char *handle_debug_or_trace(int handler, struct ast_cli_entry *e, int cmd
 				strcpy(ml->module, mod);
 				AST_RWLIST_INSERT_TAIL(modules, ml, entry);
 			}
-			ast_set_flag(&ast_options, module_option);
+			ast_set_flag64(&ast_options, module_option);
 
 			ast_cli(a->fd, "Core %s was %d and has been set to %u for '%s'.\n", handler_name,
 				oldval, ml->level, ml->module);
@@ -555,7 +555,7 @@ static char *handle_debug_or_trace(int handler, struct ast_cli_entry *e, int cmd
 		while ((ml = AST_RWLIST_REMOVE_HEAD(modules, entry))) {
 			ast_free(ml);
 		}
-		ast_clear_flag(&ast_options, AST_OPT_FLAG_DEBUG_MODULE);
+		ast_clear_flag64(&ast_options, AST_OPT_FLAG_DEBUG_MODULE);
 		AST_RWLIST_UNLOCK(modules);
 	}
 	oldval = *core_option;
@@ -1659,6 +1659,7 @@ static char *handle_showchan(struct ast_cli_entry *e, int cmd, struct ast_cli_ar
 	ast_callid callid;
 	char callid_buf[32];
 	int stream_num;
+	RAII_VAR(char *, tenant_id, NULL, ast_free);
 
 	switch (cmd) {
 	case CLI_INIT:
@@ -1717,12 +1718,17 @@ static char *handle_showchan(struct ast_cli_entry *e, int cmd, struct ast_cli_ar
 		ast_callid_strnprint(callid_buf, sizeof(callid_buf), callid);
 	}
 
+	if (!ast_strlen_zero(ast_channel_tenantid(chan))) {
+		ast_asprintf(&tenant_id, "       TenantID: %s\n", ast_channel_tenantid(chan));
+	}
+
 	ast_str_append(&output, 0,
 		" -- General --\n"
 		"           Name: %s\n"
 		"           Type: %s\n"
 		"       UniqueID: %s\n"
 		"       LinkedID: %s\n"
+		"%s"
 		"      Caller ID: %s\n"
 		" Caller ID Name: %s\n"
 		"Connected Line ID: %s\n"
@@ -1748,11 +1754,12 @@ static char *handle_showchan(struct ast_cli_entry *e, int cmd, struct ast_cli_ar
 		"   Pickup Group: %llu\n"
 		"    Application: %s\n"
 		"           Data: %s\n"
-		" Call Identifer: %s\n",
+		" Call Identifier: %s\n",
 		ast_channel_name(chan),
 		ast_channel_tech(chan)->type,
 		ast_channel_uniqueid(chan),
 		ast_channel_linkedid(chan),
+		!ast_strlen_zero(tenant_id) ? tenant_id : "",
 		S_COR(ast_channel_caller(chan)->id.number.valid,
 		      ast_channel_caller(chan)->id.number.str, "(N/A)"),
 		S_COR(ast_channel_caller(chan)->id.name.valid,
@@ -1964,7 +1971,7 @@ static char *handle_cli_wait_fullybooted(struct ast_cli_entry *e, int cmd, struc
 		return NULL;
 	}
 
-	while (!ast_test_flag(&ast_options, AST_OPT_FLAG_FULLY_BOOTED)) {
+	while (!ast_fully_booted) {
 		usleep(100);
 	}
 
